@@ -1,34 +1,5 @@
-/*
- * Copyright 2014-2019, Intel Corporation
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *     * Redistributions of source code must retain the above copyright
- *       notice, this list of conditions and the following disclaimer.
- *
- *     * Redistributions in binary form must reproduce the above copyright
- *       notice, this list of conditions and the following disclaimer in
- *       the documentation and/or other materials provided with the
- *       distribution.
- *
- *     * Neither the name of the copyright holder nor the names of its
- *       contributors may be used to endorse or promote products derived
- *       from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- */
+// SPDX-License-Identifier: BSD-3-Clause
+/* Copyright 2014-2024, Intel Corporation */
 
 /*
  * file.c -- file utilities
@@ -43,94 +14,17 @@
 #include <limits.h>
 #include <sys/file.h>
 #include <sys/mman.h>
-
-#if !defined(_WIN32) && !defined(__FreeBSD__)
 #include <sys/sysmacros.h>
-#endif
 
+#include "../libpmem2/config.h"
+#include "../libpmem2/pmem2_utils.h"
 #include "file.h"
 #include "os.h"
 #include "out.h"
 #include "mmap.h"
 
-#define MAX_SIZE_LENGTH 64
-
 #define DEVICE_DAX_ZERO_LEN (2 * MEGABYTE)
 
-#ifndef _WIN32
-/*
- * device_dax_stat_size -- (internal) checks the size of a given
- * dax device from given stat structure
- */
-static ssize_t
-device_dax_stat_size(os_stat_t *st)
-{
-	char spath[PATH_MAX];
-	snprintf(spath, PATH_MAX, "/sys/dev/char/%u:%u/size",
-		os_major(st->st_rdev), os_minor(st->st_rdev));
-
-	LOG(4, "device size path \"%s\"", spath);
-
-	int fd = os_open(spath, O_RDONLY);
-	if (fd < 0) {
-		ERR("!open \"%s\"", spath);
-		return -1;
-	}
-
-	ssize_t size = -1;
-
-	char sizebuf[MAX_SIZE_LENGTH + 1];
-	ssize_t nread;
-	if ((nread = read(fd, sizebuf, MAX_SIZE_LENGTH)) < 0) {
-		ERR("!read");
-		goto out;
-	}
-
-	sizebuf[nread] = 0; /* null termination */
-
-	char *endptr;
-
-	int olderrno = errno;
-	errno = 0;
-
-	size = strtoll(sizebuf, &endptr, 0);
-	if (endptr == sizebuf || *endptr != '\n' ||
-	    ((size == LLONG_MAX || size == LLONG_MIN) && errno == ERANGE)) {
-		ERR("invalid device size %s", sizebuf);
-		size = -1;
-		goto out;
-	}
-
-	errno = olderrno;
-
-out:
-	olderrno = errno;
-	(void) os_close(fd);
-	errno = olderrno;
-
-	LOG(4, "device size %zu", size);
-	return size;
-}
-
-/*
- * device_dax_file_size -- (internal) checks the size of a given dax device
- */
-static ssize_t
-device_dax_file_size(const char *path)
-{
-	LOG(3, "path \"%s\"", path);
-
-	os_stat_t st;
-
-	if (os_stat(path, &st) < 0) {
-		ERR("!stat \"%s\"", path);
-		return -1;
-	}
-
-	return device_dax_stat_size(&st);
-}
-#endif
-
 /*
  * util_file_exists -- checks whether file exists
  */
@@ -143,7 +37,7 @@ util_file_exists(const char *path)
 		return 1;
 
 	if (errno != ENOENT) {
-		ERR("!os_access \"%s\"", path);
+		ERR_W_ERRNO("os_access \"%s\"", path);
 		return -1;
 	}
 
@@ -167,36 +61,22 @@ util_file_exists(const char *path)
 enum file_type
 util_stat_get_type(const os_stat_t *st)
 {
-#ifdef _WIN32
-	return TYPE_NORMAL;
-#else
-	if (!S_ISCHR(st->st_mode)) {
-		LOG(4, "not a character device");
+	enum pmem2_file_type type;
+
+	int ret = pmem2_get_type_from_stat(st, &type);
+	if (ret) {
+		errno = pmem2_err_to_errno(ret);
+		return OTHER_ERROR;
+	}
+
+	if (type == PMEM2_FTYPE_REG || type == PMEM2_FTYPE_DIR)
 		return TYPE_NORMAL;
-	}
 
-	char spath[PATH_MAX];
-	snprintf(spath, PATH_MAX, "/sys/dev/char/%u:%u/subsystem",
-		os_major(st->st_rdev), os_minor(st->st_rdev));
+	if (type == PMEM2_FTYPE_DEVDAX)
+		return TYPE_DEVDAX;
 
-	LOG(4, "device subsystem path \"%s\"", spath);
-
-	char npath[PATH_MAX];
-	char *rpath = realpath(spath, npath);
-	if (rpath == NULL) {
-		ERR("!realpath \"%s\"", spath);
-		return OTHER_ERROR;
-	}
-
-	char *basename = strrchr(rpath, '/');
-	if (!basename || strcmp("dax", basename + 1) != 0) {
-		LOG(3, "%s path does not match device dax prefix path", rpath);
-		errno = EINVAL;
-		return OTHER_ERROR;
-	}
-
-	return TYPE_DEVDAX;
-#endif
+	ASSERTinfo(0, "unhandled file type in util_stat_get_type");
+	return OTHER_ERROR;
 }
 
 /*
@@ -208,18 +88,14 @@ util_fd_get_type(int fd)
 {
 	LOG(3, "fd %d", fd);
 
-#ifdef _WIN32
-	return TYPE_NORMAL;
-#else
 	os_stat_t st;
 
 	if (os_fstat(fd, &st) < 0) {
-		ERR("!fstat");
+		ERR_W_ERRNO("fstat");
 		return OTHER_ERROR;
 	}
 
 	return util_stat_get_type(&st);
-#endif
 }
 
 /*
@@ -232,7 +108,7 @@ util_file_get_type(const char *path)
 	LOG(3, "path \"%s\"", path);
 
 	if (path == NULL) {
-		ERR("invalid (NULL) path");
+		ERR_WO_ERRNO("invalid (NULL) path");
 		errno = EINVAL;
 		return OTHER_ERROR;
 	}
@@ -244,18 +120,14 @@ util_file_get_type(const char *path)
 	if (!exists)
 		return NOT_EXISTS;
 
-#ifdef _WIN32
-	return TYPE_NORMAL;
-#else
 	os_stat_t st;
 
 	if (os_stat(path, &st) < 0) {
-		ERR("!stat");
+		ERR_W_ERRNO("stat");
 		return OTHER_ERROR;
 	}
 
 	return util_stat_get_type(&st);
-#endif
 }
 
 /*
@@ -266,24 +138,16 @@ util_file_get_size(const char *path)
 {
 	LOG(3, "path \"%s\"", path);
 
-	int file_type = util_file_get_type(path);
-	if (file_type < 0)
-		return -1;
-
-#ifndef _WIN32
-	if (file_type == TYPE_DEVDAX) {
-		return device_dax_file_size(path);
-	}
-#endif
-
-	os_stat_t stbuf;
-	if (os_stat(path, &stbuf) < 0) {
-		ERR("!stat \"%s\"", path);
+	int fd = os_open(path, O_RDONLY);
+	if (fd < 0) {
+		ERR_W_ERRNO("open");
 		return -1;
 	}
 
-	LOG(4, "file length %zu", stbuf.st_size);
-	return stbuf.st_size;
+	ssize_t size = util_fd_get_size(fd);
+	(void) close(fd);
+
+	return size;
 }
 
 /*
@@ -294,25 +158,35 @@ util_fd_get_size(int fd)
 {
 	LOG(3, "fd %d", fd);
 
-	os_stat_t st;
+	struct pmem2_source *src;
+	size_t size;
+	int ret;
 
-	if (os_fstat(fd, &st) < 0) {
-		ERR("!fstat");
-		return OTHER_ERROR;
-	}
-
-	int file_type = util_stat_get_type(&st);
-	if (file_type < 0)
+	if ((ret = pmem2_source_from_fd(&src, fd)) != 0) {
+		errno = pmem2_err_to_errno(ret);
 		return -1;
-
-#ifndef _WIN32
-	if (file_type == TYPE_DEVDAX) {
-		return device_dax_stat_size(&st);
 	}
-#endif
 
-	LOG(4, "file length %zu", st.st_size);
-	return st.st_size;
+	ret = pmem2_source_size(src, &size);
+
+	pmem2_source_delete(&src);
+
+	if (ret) {
+		errno = pmem2_err_to_errno(ret);
+		return -1;
+	}
+
+	/* size is unsigned, this function returns signed */
+	if (size >= INT64_MAX) {
+		errno = ERANGE;
+		ERR_WO_ERRNO(
+			"file size (%ld) too big to be represented in 64-bit signed integer",
+			size);
+		return -1;
+	}
+
+	LOG(4, "file length %zu", size);
+	return (ssize_t)size;
 }
 
 /*
@@ -327,24 +201,21 @@ util_file_map_whole(const char *path)
 	int olderrno;
 	void *addr = NULL;
 	int flags = O_RDWR;
-#ifdef _WIN32
-	flags |= O_BINARY;
-#endif
 
 	if ((fd = os_open(path, flags)) < 0) {
-		ERR("!open \"%s\"", path);
+		ERR_W_ERRNO("open \"%s\"", path);
 		return NULL;
 	}
 
-	ssize_t size = util_file_get_size(path);
+	ssize_t size = util_fd_get_size(fd);
 	if (size < 0) {
-		LOG(2, "cannot determine file length \"%s\"", path);
+		CORE_LOG_ERROR("cannot determine file length \"%s\"", path);
 		goto out;
 	}
 
 	addr = util_map(fd, 0, (size_t)size, MAP_SHARED, 0, 0, NULL);
 	if (addr == NULL) {
-		LOG(2, "failed to map entire file \"%s\"", path);
+		CORE_LOG_ERROR("failed to map entire file \"%s\"", path);
 		goto out;
 	}
 
@@ -368,38 +239,37 @@ util_file_zero(const char *path, os_off_t off, size_t len)
 	int olderrno;
 	int ret = 0;
 	int flags = O_RDWR;
-#ifdef _WIN32
-	flags |= O_BINARY;
-#endif
 
 	if ((fd = os_open(path, flags)) < 0) {
-		ERR("!open \"%s\"", path);
+		ERR_W_ERRNO("open \"%s\"", path);
 		return -1;
 	}
 
-	ssize_t size = util_file_get_size(path);
+	ssize_t size = util_fd_get_size(fd);
 	if (size < 0) {
-		LOG(2, "cannot determine file length \"%s\"", path);
+		CORE_LOG_ERROR("cannot determine file length \"%s\"", path);
 		ret = -1;
 		goto out;
 	}
 
 	if (off > size) {
-		LOG(2, "offset beyond file length, %ju > %ju", off, size);
+		CORE_LOG_ERROR("offset beyond file length, %ju > %ju", off,
+			size);
 		ret = -1;
 		goto out;
 	}
 
 	if ((size_t)off + len > (size_t)size) {
-		LOG(2, "requested size of write goes beyond the file length, "
-					"%zu > %zu", (size_t)off + len, size);
+		CORE_LOG_WARNING(
+			"requested size of write goes beyond the file length, %zu > %zu",
+			(size_t)off + len, size);
 		LOG(4, "adjusting len to %zu", size - off);
 		len = (size_t)(size - off);
 	}
 
 	void *addr = util_map(fd, 0, (size_t)size, MAP_SHARED, 0, 0, NULL);
 	if (addr == NULL) {
-		LOG(2, "failed to map entire file \"%s\"", path);
+		CORE_LOG_ERROR("failed to map entire file \"%s\"", path);
 		ret = -1;
 		goto out;
 	}
@@ -434,7 +304,7 @@ util_file_pwrite(const char *path, const void *buffer, size_t size,
 	if (type == TYPE_NORMAL) {
 		int fd = util_file_open(path, NULL, 0, O_RDWR);
 		if (fd < 0) {
-			LOG(2, "failed to open file \"%s\"", path);
+			CORE_LOG_ERROR("failed to open file \"%s\"", path);
 			return -1;
 		}
 
@@ -447,21 +317,22 @@ util_file_pwrite(const char *path, const void *buffer, size_t size,
 
 	ssize_t file_size = util_file_get_size(path);
 	if (file_size < 0) {
-		LOG(2, "cannot determine file length \"%s\"", path);
+		CORE_LOG_ERROR("cannot determine file length \"%s\"", path);
 		return -1;
 	}
 
 	size_t max_size = (size_t)(file_size - offset);
 	if (size > max_size) {
-		LOG(2, "requested size of write goes beyond the file length, "
-			"%zu > %zu", size, max_size);
+		CORE_LOG_WARNING(
+			"requested size of write goes beyond the file length, %zu > %zu",
+			size, max_size);
 		LOG(4, "adjusting size to %zu", max_size);
 		size = max_size;
 	}
 
 	void *addr = util_file_map_whole(path);
 	if (addr == NULL) {
-		LOG(2, "failed to map entire file \"%s\"", path);
+		CORE_LOG_ERROR("failed to map entire file \"%s\"", path);
 		return -1;
 	}
 
@@ -487,7 +358,7 @@ util_file_pread(const char *path, void *buffer, size_t size,
 	if (type == TYPE_NORMAL) {
 		int fd = util_file_open(path, NULL, 0, O_RDONLY);
 		if (fd < 0) {
-			LOG(2, "failed to open file \"%s\"", path);
+			CORE_LOG_ERROR("failed to open file \"%s\"", path);
 			return -1;
 		}
 
@@ -500,21 +371,22 @@ util_file_pread(const char *path, void *buffer, size_t size,
 
 	ssize_t file_size = util_file_get_size(path);
 	if (file_size < 0) {
-		LOG(2, "cannot determine file length \"%s\"", path);
+		CORE_LOG_ERROR("cannot determine file length \"%s\"", path);
 		return -1;
 	}
 
 	size_t max_size = (size_t)(file_size - offset);
 	if (size > max_size) {
-		LOG(2, "requested size of read goes beyond the file length, "
-			"%zu > %zu", size, max_size);
+		CORE_LOG_WARNING(
+			"requested size of read goes beyond the file length, %zu > %zu",
+			size, max_size);
 		LOG(4, "adjusting size to %zu", max_size);
 		size = max_size;
 	}
 
 	void *addr = util_file_map_whole(path);
 	if (addr == NULL) {
-		LOG(2, "failed to map entire file \"%s\"", path);
+		CORE_LOG_ERROR("failed to map entire file \"%s\"", path);
 		return -1;
 	}
 
@@ -534,13 +406,13 @@ util_file_create(const char *path, size_t size, size_t minsize)
 	ASSERTne(size, 0);
 
 	if (size < minsize) {
-		ERR("size %zu smaller than %zu", size, minsize);
+		ERR_WO_ERRNO("size %zu smaller than %zu", size, minsize);
 		errno = EINVAL;
 		return -1;
 	}
 
 	if (((os_off_t)size) < 0) {
-		ERR("invalid size (%zu) for os_off_t", size);
+		ERR_WO_ERRNO("invalid size (%zu) for os_off_t", size);
 		errno = EFBIG;
 		return -1;
 	}
@@ -548,30 +420,24 @@ util_file_create(const char *path, size_t size, size_t minsize)
 	int fd;
 	int mode;
 	int flags = O_RDWR | O_CREAT | O_EXCL;
-#ifndef _WIN32
 	mode = 0;
-#else
-	mode = S_IWRITE | S_IREAD;
-	flags |= O_BINARY;
-#endif
 
 	/*
 	 * Create file without any permission. It will be granted once
 	 * initialization completes.
 	 */
 	if ((fd = os_open(path, flags, mode)) < 0) {
-		ERR("!open \"%s\"", path);
+		ERR_W_ERRNO("open \"%s\"", path);
 		return -1;
 	}
 
 	if ((errno = os_posix_fallocate(fd, 0, (os_off_t)size)) != 0) {
-		ERR("!posix_fallocate \"%s\", %zu", path, size);
+		ERR_W_ERRNO("posix_fallocate \"%s\", %zu", path, size);
 		goto err;
 	}
 
-	/* for windows we can't flock until after we fallocate */
 	if (os_flock(fd, OS_LOCK_EX | OS_LOCK_NB) < 0) {
-		ERR("!flock \"%s\"", path);
+		ERR_W_ERRNO("flock \"%s\"", path);
 		goto err;
 	}
 
@@ -599,17 +465,13 @@ util_file_open(const char *path, size_t *size, size_t minsize, int flags)
 	int oerrno;
 	int fd;
 
-#ifdef _WIN32
-	flags |= O_BINARY;
-#endif
-
 	if ((fd = os_open(path, flags)) < 0) {
-		ERR("!open \"%s\"", path);
+		ERR_W_ERRNO("open \"%s\"", path);
 		return -1;
 	}
 
 	if (os_flock(fd, OS_LOCK_EX | OS_LOCK_NB) < 0) {
-		ERR("!flock \"%s\"", path);
+		ERR_W_ERRNO("flock \"%s\"", path);
 		(void) os_close(fd);
 		return -1;
 	}
@@ -618,15 +480,15 @@ util_file_open(const char *path, size_t *size, size_t minsize, int flags)
 		if (size)
 			ASSERTeq(*size, 0);
 
-		ssize_t actual_size = util_file_get_size(path);
+		ssize_t actual_size = util_fd_get_size(fd);
 		if (actual_size < 0) {
-			ERR("stat \"%s\": negative size", path);
+			ERR_WO_ERRNO("stat \"%s\": negative size", path);
 			errno = EINVAL;
 			goto err;
 		}
 
 		if ((size_t)actual_size < minsize) {
-			ERR("size %zu smaller than %zu",
+			ERR_WO_ERRNO("size %zu smaller than %zu",
 					(size_t)actual_size, minsize);
 			errno = EINVAL;
 			goto err;
@@ -642,7 +504,7 @@ util_file_open(const char *path, size_t *size, size_t minsize, int flags)
 err:
 	oerrno = errno;
 	if (os_flock(fd, OS_LOCK_UN))
-		ERR("!flock unlock");
+		ERR_W_ERRNO("flock unlock");
 	(void) os_close(fd);
 	errno = oerrno;
 	return -1;
@@ -663,13 +525,6 @@ util_unlink(const char *path)
 	if (type == TYPE_DEVDAX) {
 		return util_file_zero(path, 0, DEVICE_DAX_ZERO_LEN);
 	} else {
-#ifdef _WIN32
-		/* on Windows we can not unlink Read-Only files */
-		if (os_chmod(path, S_IREAD | S_IWRITE) == -1) {
-			ERR("!chmod \"%s\"", path);
-			return -1;
-		}
-#endif
 		return os_unlink(path);
 	}
 }
@@ -687,16 +542,9 @@ util_unlink_flock(const char *path)
 {
 	LOG(3, "path \"%s\"", path);
 
-#ifdef WIN32
-	/*
-	 * On Windows it is not possible to unlink the
-	 * file if it is flocked.
-	 */
-	return util_unlink(path);
-#else
 	int fd = util_file_open(path, NULL, 0, O_RDONLY);
 	if (fd < 0) {
-		LOG(2, "failed to open file \"%s\"", path);
+		CORE_LOG_ERROR("failed to open file \"%s\"", path);
 		return -1;
 	}
 
@@ -705,7 +553,6 @@ util_unlink_flock(const char *path)
 	(void) os_close(fd);
 
 	return ret;
-#endif
 }
 
 /*
