@@ -1,14 +1,12 @@
 // SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2014-2021, Intel Corporation */
+/* Copyright 2014-2024, Intel Corporation */
 
 /*
  * file_posix.c -- Posix versions of file APIs
  */
 
-#ifndef __FreeBSD__
 /* for O_TMPFILE */
 #define _GNU_SOURCE
-#endif
 
 #include <errno.h>
 #include <signal.h>
@@ -114,7 +112,7 @@ device_dax_alignment(const char *path)
 
 	int fd = os_open(path, O_RDONLY);
 	if (fd == -1) {
-		LOG(1, "Cannot open file %s", path);
+		CORE_LOG_ERROR("Cannot open file %s", path);
 		return size;
 	}
 
@@ -157,7 +155,7 @@ util_ddax_region_find(const char *path, unsigned *region_id)
 	int ret;
 
 	if (os_stat(path, &st) < 0) {
-		ERR("!stat \"%s\"", path);
+		ERR_W_ERRNO("stat \"%s\"", path);
 		return -1;
 	}
 
