@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2018-2021, Intel Corporation */
+/* Copyright 2018-2024, Intel Corporation */
 
 /*
  * ravl.c -- implementation of a RAVL tree
@@ -9,7 +9,9 @@
 #include <stdlib.h>
 #include <string.h>
 #include <errno.h>
+
 #include "out.h"
+#include "core_assert.h"
 #include "ravl.h"
 #include "alloc.h"
 
@@ -46,7 +48,7 @@ ravl_new_sized(ravl_compare *compare, size_t data_size)
 {
 	struct ravl *r = Malloc(sizeof(*r));
 	if (r == NULL) {
-		ERR("!Malloc");
+		ERR_W_ERRNO("Malloc");
 		return r;
 	}
 
@@ -162,7 +164,7 @@ ravl_new_node(struct ravl *ravl, ravl_constr constr, const void *arg)
 {
 	struct ravl_node *n = Malloc(sizeof(*n) + ravl->data_size);
 	if (n == NULL) {
-		ERR("!Malloc");
+		ERR_W_ERRNO("Malloc");
 		return n;
 	}
 
