@@ -1,5 +1,6 @@
 // SPDX-License-Identifier: BSD-3-Clause
 /* Copyright 2014-2024, Intel Corporation */
+/* Copyright 2025, Hewlett Packard Enterprise Development LP */
 
 /*
  * obj.c -- transactional object store implementation
@@ -1046,6 +1047,23 @@ no_valid_env:
 	return OBJ_NLANES;
 }
 
+static inline int
+pool_attr_adjust(struct pool_attr *attr)
+{
+	/* force set SDS feature */
+	if (SDS_at_create) {
+		if (!(attr->features.incompat & POOL_FEAT_SDS)) {
+			ERR_WO_ERRNO(
+				"The SDS feature cannot be force-enabled, as it was disabled at compile time.");
+			return EINVAL;
+		}
+	} else {
+		attr->features.incompat &= ~POOL_FEAT_SDS; /* off */
+	}
+
+	return 0;
+}
+
 /*
  * pmemobj_createU -- create a transactional memory pool (set)
  */
@@ -1059,6 +1077,7 @@ pmemobj_createU(const char *path, const char *layout,
 
 	PMEMobjpool *pop;
 	struct pool_set *set;
+	int ret;
 
 	/* check length of layout */
 	if (layout && (strlen(layout) >= PMEMOBJ_MAX_LAYOUT)) {
@@ -1077,12 +1096,11 @@ pmemobj_createU(const char *path, const char *layout,
 	unsigned runtime_nlanes = obj_get_nlanes();
 
 	struct pool_attr adj_pool_attr = Obj_create_attr;
-
-	/* force set SDS feature */
-	if (SDS_at_create)
-		adj_pool_attr.features.incompat |= POOL_FEAT_SDS;
-	else
-		adj_pool_attr.features.incompat &= ~POOL_FEAT_SDS;
+	ret = pool_attr_adjust(&adj_pool_attr);
+	if (ret != 0) {
+		errno = ret;
+		return NULL;
+	}
 
 	if (util_pool_create(&set, path, poolsize, PMEMOBJ_MIN_POOL,
 			PMEMOBJ_MIN_PART, &adj_pool_attr, &runtime_nlanes,
@@ -1233,7 +1251,14 @@ static int
 obj_pool_open(struct pool_set **set, const char *path, unsigned flags,
 	unsigned *nlanes)
 {
-	if (util_pool_open(set, path, PMEMOBJ_MIN_PART, &Obj_open_attr,
+	struct pool_attr adj_pool_attr = Obj_open_attr;
+	int ret = pool_attr_adjust(&adj_pool_attr);
+	if (ret != 0) {
+		errno = ret;
+		return -1;
+	}
+
+	if (util_pool_open(set, path, PMEMOBJ_MIN_PART, &adj_pool_attr,
 				nlanes, NULL, flags) != 0) {
 		CORE_LOG_ERROR("cannot open pool or pool set");
 		return -1;
