@@ -7,19 +7,6 @@
 
 #include "vec.h"
 
-#define BLK_DEPR_STR "Libpmemblk is deprecated."
-#define LOG_DEPR_STR "Libpmemlog is deprecated."
-#ifdef _WIN32
-#define PMEMBLK_DEPR_ATTR __declspec(deprecated(BLK_DEPR_STR))
-#define PMEMLOG_DEPR_ATTR __declspec(deprecated(LOG_DEPR_STR))
-
-#define WIN_DEPR_STR "Windows support is deprecated."
-#define WIN_DEPR_ATTR __declspec(deprecated(WIN_DEPR_STR))
-#else
-#define PMEMBLK_DEPR_ATTR __attribute__((deprecated(BLK_DEPR_STR)))
-#define PMEMLOG_DEPR_ATTR __attribute__((deprecated(LOG_DEPR_STR)))
-#endif
-
 /*
  * Verbose levels used in application:
  *
@@ -68,17 +55,6 @@ struct pmempool_info_args {
 	int vdata;		/* verbosity level for data dump */
 	int vhdrdump;		/* verbosity level for headers hexdump */
 	int vstats;		/* verbosity level for statistics */
-	struct {
-		size_t walk;		/* data chunk size */
-	} log; /* deprecated */
-	struct {
-		int vmap;	/* verbosity level for BTT Map */
-		int vflog;	/* verbosity level for BTT FLOG */
-		int vbackup;	/* verbosity level for BTT Info backup */
-		bool skip_zeros; /* skip blocks marked with zero flag */
-		bool skip_error; /* skip blocks marked with error flag */
-		bool skip_no_flag; /* skip blocks not marked with any flag */
-	} blk; /* deprecated */
 	struct {
 		int vlanes;		/* verbosity level for lanes */
 		int vroot;
@@ -100,16 +76,6 @@ struct pmempool_info_args {
 	} obj;
 };
 
-/*
- * pmem_blk_stats -- structure with statistics for pmemblk (DEPRECATED)
- */
-struct pmem_blk_stats {
-	uint32_t total;		/* number of processed blocks */
-	uint32_t zeros;		/* number of blocks marked by zero flag */
-	uint32_t errors;	/* number of blocks marked by error flag */
-	uint32_t noflag;	/* number of blocks not marked with any flag */
-};
-
 struct pmem_obj_class_stats {
 	uint64_t n_units;
 	uint64_t n_used;
@@ -154,9 +120,6 @@ struct pmem_info {
 	struct pool_set *poolset;
 	pmem_pool_type_t type;
 	struct pmem_pool_params params;
-	struct {
-		struct pmem_blk_stats stats;
-	} blk; /* deprecated */
 	struct {
 		struct pmemobjpool *pop;
 		struct palloc_heap *heap;
@@ -168,24 +131,9 @@ struct pmem_info {
 	} obj;
 };
 
-#ifdef _WIN32
-WIN_DEPR_ATTR
-#endif
 int pmempool_info_func(const char *appname, int argc, char *argv[]);
-#ifdef _WIN32
-WIN_DEPR_ATTR
-#endif
 void pmempool_info_help(const char *appname);
 
-#ifdef _WIN32
-WIN_DEPR_ATTR
-#endif
 int pmempool_info_read(struct pmem_info *pip, void *buff,
 		size_t nbytes, uint64_t off);
-PMEMBLK_DEPR_ATTR int pmempool_info_blk(struct pmem_info *pip);
-PMEMLOG_DEPR_ATTR int pmempool_info_log(struct pmem_info *pip);
-#ifdef _WIN32
-WIN_DEPR_ATTR
-#endif
 int pmempool_info_obj(struct pmem_info *pip);
-PMEMBLK_DEPR_ATTR int pmempool_info_btt(struct pmem_info *pip);
